==> firebase-firestore-23.0.4-javadoc.jar: lists.js <==
var DATA = [
      { id:0, label:"com.google.firebase.firestore", link:"reference/com/google/firebase/firestore/package-summary.html", type:"package" },
      { id:1, label:"com.google.firebase.firestore.Blob", link:"reference/com/google/firebase/firestore/Blob.html", type:"class" },
      { id:2, label:"com.google.firebase.firestore.CollectionReference", link:"reference/com/google/firebase/firestore/CollectionReference.html", type:"class" },
      { id:3, label:"com.google.firebase.firestore.DocumentChange", link:"reference/com/google/firebase/firestore/DocumentChange.html", type:"class" },
      { id:4, label:"com.google.firebase.firestore.DocumentChange.Type", link:"reference/com/google/firebase/firestore/DocumentChange.Type.html", type:"class" },
      { id:5, label:"com.google.firebase.firestore.DocumentId", link:"reference/com/google/firebase/firestore/DocumentId.html", type:"class" },
      { id:6, label:"com.google.firebase.firestore.DocumentReference", link:"reference/com/google/firebase/firestore/DocumentReference.html", type:"class" },
      { id:7, label:"com.google.firebase.firestore.DocumentSnapshot", link:"reference/com/google/firebase/firestore/DocumentSnapshot.html", type:"class" },
      { id:8, label:"com.google.firebase.firestore.DocumentSnapshot.ServerTimestampBehavior", link:"reference/com/google/firebase/firestore/DocumentSnapshot.ServerTimestampBehavior.html", type:"class" },
      { id:9, label:"com.google.firebase.firestore.EventListener", link:"reference/com/google/firebase/firestore/EventListener.html", type:"class" },
      { id:10, label:"com.google.firebase.firestore.Exclude", link:"reference/com/google/firebase/firestore/Exclude.html", type:"class" },
      { id:11, label:"com.google.firebase.firestore.FieldPath", link:"reference/com/google/firebase/firestore/FieldPath.html", type:"class" },
      { id:12, label:"com.google.firebase.firestore.FieldValue", link:"reference/com/google/firebase/firestore/FieldValue.html", type:"class" },
      { id:13, label:"com.google.firebase.firestore.FirebaseFirestore", link:"reference/com/google/firebase/firestore/FirebaseFirestore.html", type:"class" },
      { id:14, label:"com.google.firebase.firestore.FirebaseFirestoreException", link:"reference/com/google/firebase/firestore/FirebaseFirestoreException.html", type:"class" },
      { id:15, label:"com.google.firebase.firestore.FirebaseFirestoreException.Code", link:"reference/com/google/firebase/firestore/FirebaseFirestoreException.Code.html", type:"class" },
      { id:16, label:"com.google.firebase.firestore.FirebaseFirestoreSettings", link:"reference/com/google/firebase/firestore/FirebaseFirestoreSettings.html", type:"class" },
      { id:17, label:"com.google.firebase.firestore.FirebaseFirestoreSettings.Builder", link:"reference/com/google/firebase/firestore/FirebaseFirestoreSettings.Builder.html", type:"class" },
      { id:18, label:"com.google.firebase.firestore.GeoPoint", link:"reference/com/google/firebase/firestore/GeoPoint.html", type:"class" },
      { id:19, label:"com.google.firebase.firestore.IgnoreExtraProperties", link:"reference/com/google/firebase/firestore/IgnoreExtraProperties.html", type:"class" },
      { id:20, label:"com.google.firebase.firestore.ListenerRegistration", link:"reference/com/google/firebase/firestore/ListenerRegistration.html", type:"class" },
      { id:21, label:"com.google.firebase.firestore.LoadBundleTask", link:"reference/com/google/firebase/firestore/LoadBundleTask.html", type:"class" },
      { id:22, label:"com.google.firebase.firestore.LoadBundleTaskProgress", link:"reference/com/google/firebase/firestore/LoadBundleTaskProgress.html", type:"class" },
      { id:23, label:"com.google.firebase.firestore.LoadBundleTaskProgress.TaskState", link:"reference/com/google/firebase/firestore/LoadBundleTaskProgress.TaskState.html", type:"class" },
      { id:24, label:"com.google.firebase.firestore.MetadataChanges", link:"reference/com/google/firebase/firestore/MetadataChanges.html", type:"class" },
      { id:25, label:"com.google.firebase.firestore.OnProgressListener", link:"reference/com/google/firebase/firestore/OnProgressListener.html", type:"class" },
      { id:26, label:"com.google.firebase.firestore.PropertyName", link:"reference/com/google/firebase/firestore/PropertyName.html", type:"class" },
      { id:27, label:"com.google.firebase.firestore.Query", link:"reference/com/google/firebase/firestore/Query.html", type:"class" },
      { id:28, label:"com.google.firebase.firestore.Query.Direction", link:"reference/com/google/firebase/firestore/Query.Direction.html", type:"class" },
      { id:29, label:"com.google.firebase.firestore.QueryDocumentSnapshot", link:"reference/com/google/firebase/firestore/QueryDocumentSnapshot.html", type:"class" },
      { id:30, label:"com.google.firebase.firestore.QuerySnapshot", link:"reference/com/google/firebase/firestore/QuerySnapshot.html", type:"class" },
      { id:31, label:"com.google.firebase.firestore.ServerTimestamp", link:"reference/com/google/firebase/firestore/ServerTimestamp.html", type:"class" },
      { id:32, label:"com.google.firebase.firestore.SetOptions", link:"reference/com/google/firebase/firestore/SetOptions.html", type:"class" },
      { id:33, label:"com.google.firebase.firestore.SnapshotMetadata", link:"reference/com/google/firebase/firestore/SnapshotMetadata.html", type:"class" },
      { id:34, label:"com.google.firebase.firestore.Source", link:"reference/com/google/firebase/firestore/Source.html", type:"class" },
      { id:35, label:"com.google.firebase.firestore.ThrowOnExtraProperties", link:"reference/com/google/firebase/firestore/ThrowOnExtraProperties.html", type:"class" },
      { id:36, label:"com.google.firebase.firestore.Transaction", link:"reference/com/google/firebase/firestore/Transaction.html", type:"class" },
      { id:37, label:"com.google.firebase.firestore.Transaction.Function", link:"reference/com/google/firebase/firestore/Transaction.Function.html", type:"class" },
      { id:38, label:"com.google.firebase.firestore.WriteBatch", link:"reference/com/google/firebase/firestore/WriteBatch.html", type:"class" },
      { id:39, label:"com.google.firebase.firestore.WriteBatch.Function", link:"reference/com/google/firebase/firestore/WriteBatch.Function.html", type:"class" }

    ];

==> firebase-firestore-24.3.1-javadoc.jar: lists.js <==
var DATA = [
      { id:0, label:"com.google.firebase.firestore", link:"reference/com/google/firebase/firestore/package-summary.html", type:"package" },
      { id:1, label:"com.google.firebase.firestore.Blob", link:"reference/com/google/firebase/firestore/Blob.html", type:"class" },
      { id:2, label:"com.google.firebase.firestore.CollectionReference", link:"reference/com/google/firebase/firestore/CollectionReference.html", type:"class" },
      { id:3, label:"com.google.firebase.firestore.DocumentChange", link:"reference/com/google/firebase/firestore/DocumentChange.html", type:"class" },
      { id:4, label:"com.google.firebase.firestore.DocumentChange.Type", link:"reference/com/google/firebase/firestore/DocumentChange.Type.html", type:"class" },
      { id:5, label:"com.google.firebase.firestore.DocumentId", link:"reference/com/google/firebase/firestore/DocumentId.html", type:"class" },
      { id:6, label:"com.google.firebase.firestore.DocumentReference", link:"reference/com/google/firebase/firestore/DocumentReference.html", type:"class" },
      { id:7, label:"com.google.firebase.firestore.DocumentSnapshot", link:"reference/com/google/firebase/firestore/DocumentSnapshot.html", type:"class" },
      { id:8, label:"com.google.firebase.firestore.DocumentSnapshot.ServerTimestampBehavior", link:"reference/com/google/firebase/firestore/DocumentSnapshot.ServerTimestampBehavior.html", type:"class" },
      { id:9, label:"com.google.firebase.firestore.EventListener", link:"reference/com/google/firebase/firestore/EventListener.html", type:"class" },
      { id:10, label:"com.google.firebase.firestore.Exclude", link:"reference/com/google/firebase/firestore/Exclude.html", type:"class" },
      { id:11, label:"com.google.firebase.firestore.FieldPath", link:"reference/com/google/firebase/firestore/FieldPath.html", type:"class" },
      { id:12, label:"com.google.firebase.firestore.FieldValue", link:"reference/com/google/firebase/firestore/FieldValue.html", type:"class" },
      { id:13, label:"com.google.firebase.firestore.FirebaseFirestore", link:"reference/com/google/firebase/firestore/FirebaseFirestore.html", type:"class" },
      { id:14, label:"com.google.firebase.firestore.FirebaseFirestoreException", link:"reference/com/google/firebase/firestore/FirebaseFirestoreException.html", type:"class" },
      { id:15, label:"com.google.firebase.firestore.FirebaseFirestoreException.Code", link:"reference/com/google/firebase/firestore/FirebaseFirestoreException.Code.html", type:"class" },
      { id:16, label:"com.google.firebase.firestore.FirebaseFirestoreSettings", link:"reference/com/google/firebase/firestore/FirebaseFirestoreSettings.html", type:"class" },
      { id:17, label:"com.google.firebase.firestore.FirebaseFirestoreSettings.Builder", link:"reference/com/google/firebase/firestore/FirebaseFirestoreSettings.Builder.html", type:"class" },
      { id:18, label:"com.google.firebase.firestore.GeoPoint", link:"reference/com/google/firebase/firestore/GeoPoint.html", type:"class" },
      { id:19, label:"com.google.firebase.firestore.IgnoreExtraProperties", link:"reference/com/google/firebase/firestore/IgnoreExtraProperties.html", type:"class" },
      { id:20, label:"com.google.firebase.firestore.ListenerRegistration", link:"reference/com/google/firebase/firestore/ListenerRegistration.html", type:"class" },
      { id:21, label:"com.google.firebase.firestore.LoadBundleTask", link:"reference/com/google/firebase/firestore/LoadBundleTask.html", type:"class" },
      { id:22, label:"com.google.firebase.firestore.LoadBundleTaskProgress", link:"reference/com/google/firebase/firestore/LoadBundleTaskProgress.html", type:"class" },
      { id:23, label:"com.google.firebase.firestore.LoadBundleTaskProgress.TaskState", link:"reference/com/google/firebase/firestore/LoadBundleTaskProgress.TaskState.html", type:"class" },
      { id:24, label:"com.google.firebase.firestore.MetadataChanges", link:"reference/com/google/firebase/firestore/MetadataChanges.html", type:"class" },
      { id:25, label:"com.google.firebase.firestore.OnProgressListener", link:"reference/com/google/firebase/firestore/OnProgressListener.html", type:"class" },
      { id:26, label:"com.google.firebase.firestore.PropertyName", link:"reference/com/google/firebase/firestore/PropertyName.html", type:"class" },
      { id:27, label:"com.google.firebase.firestore.Query", link:"reference/com/google/firebase/firestore/Query.html", type:"class" },
      { id:28, label:"com.google.firebase.firestore.Query.Direction", link:"reference/com/google/firebase/firestore/Query.Direction.html", type:"class" },
      { id:29, label:"com.google.firebase.firestore.QueryDocumentSnapshot", link:"reference/com/google/firebase/firestore/QueryDocumentSnapshot.html", type:"class" },
      { id:30, label:"com.google.firebase.firestore.QuerySnapshot", link:"reference/com/google/firebase/firestore/QuerySnapshot.html", type:"class" },
      { id:31, label:"com.google.firebase.firestore.ServerTimestamp", link:"reference/com/google/firebase/firestore/ServerTimestamp.html", type:"class" },
      { id:32, label:"com.google.firebase.firestore.SetOptions", link:"reference/com/google/firebase/firestore/SetOptions.html", type:"class" },
      { id:33, label:"com.google.firebase.firestore.SnapshotMetadata", link:"reference/com/google/firebase/firestore/SnapshotMetadata.html", type:"class" },
      { id:34, label:"com.google.firebase.firestore.Source", link:"reference/com/google/firebase/firestore/Source.html", type:"class" },
      { id:35, label:"com.google.firebase.firestore.ThrowOnExtraProperties", link:"reference/com/google/firebase/firestore/ThrowOnExtraProperties.html", type:"class" },
      { id:36, label:"com.google.firebase.firestore.Transaction", link:"reference/com/google/firebase/firestore/Transaction.html", type:"class" },
      { id:37, label:"com.google.firebase.firestore.Transaction.Function", link:"reference/com/google/firebase/firestore/Transaction.Function.html", type:"class" },
      { id:38, label:"com.google.firebase.firestore.TransactionOptions", link:"reference/com/google/firebase/firestore/TransactionOptions.html", type:"class" },
      { id:39, label:"com.google.firebase.firestore.TransactionOptions.Builder", link:"reference/com/google/firebase/firestore/TransactionOptions.Builder.html", type:"class" },
      { id:40, label:"com.google.firebase.firestore.WriteBatch", link:"reference/com/google/firebase/firestore/WriteBatch.html", type:"class" },
      { id:41, label:"com.google.firebase.firestore.WriteBatch.Function", link:"reference/com/google/firebase/firestore/WriteBatch.Function.html", type:"class" }

    ];
